@@ -12,7 +12,7 @@
  *
  * Also finds out IP of specified MAC
  *
- * $Id: arping.c,v 1.51 2002/02/12 18:17:47 marvin Exp $
+ * $Id: arping.c,v 1.56 2002/11/03 19:47:58 marvin Exp $
  */
 /*
  *  Copyright (C) 2000-2002 Thomas Habets <thomas@habets.pp.se>
@@ -78,7 +78,7 @@
 #define DEBUG(a)
 #endif
 
-const float version = 1.04;
+const float version = 1.05;
 
 struct ether_addr *mymac;
 static u_char eth_xmas[ETH_ALEN] = {0xff, 0xff, 0xff, 0xff, 0xff, 0xff};
@@ -90,8 +90,8 @@ static struct timeval lastpacketsent;
 static const u_int ip_xmas = 0xffffffff;
 
 static pcap_t *pcap;
-struct bpf_program bpf_prog;
-struct in_addr net,mask;
+//static struct bpf_program bpf_prog;
+//static struct in_addr net,mask;
 #if 0
 // Use this if you want to hard-code a default interface
 static char *ifname = "eth0";
@@ -100,7 +100,7 @@ static char *ifname = NULL;
 #endif
 static u_int32_t dip = 0;
 static u_char *packet;
-struct libnet_link_int *linkint;
+static struct libnet_link_int *linkint;
 
 static unsigned int beep = 0;
 static unsigned int verbose = 0;
@@ -197,6 +197,7 @@ static void alasend(int i)
 		exit(1);
 	}
 	alarm(1);
+	DEBUG(fprintf(stderr, "Resetting timer\n"));
 #if SOLARIS
 	signal(SIGALRM, alasend);
 #endif
@@ -245,7 +246,8 @@ static void handlepacket(const char *unused, struct pcap_pkthdr *h,
 
 	if (searchmac) {
 		// ping mac
-		hip = (struct iphdr*)((char*)eth + sizeof(struct libnet_ethernet_hdr));
+		hip = (struct iphdr*)((char*)eth
+				      + sizeof(struct libnet_ethernet_hdr));
 		hicmp = (struct icmphdr*)((char*)hip + sizeof(struct iphdr));
 		if ((htons(hicmp->type) == ICMP_ECHOREPLY)
 		    && ((!memcmp(eth->h_source, eth_target, ETH_ALEN)
@@ -271,18 +273,22 @@ static void handlepacket(const char *unused, struct pcap_pkthdr *h,
 				}
 				if (!rawoutput) {
 					/*
-					 * ugly code due to non-aligned saddr (bus error on sparc)
+					 * ugly code due to non-aligned saddr
+					 * (bus error on sparc)
 					 */
 					u_int32_t tmp;
-					memcpy(&tmp, &hip->saddr, sizeof(u_int32_t));
+					memcpy(&tmp, &hip->saddr,
+					       sizeof(u_int32_t));
 					printf("%s",libnet_host_lookup(tmp,0));
 					printf(" (");
 					for (c = 0; c < ETH_ALEN-1; c++) {
 						printf("%.2x:", *cp++);
 					}
-					printf("%.2x): icmp_seq=%d time=%s", *cp,
+					printf("%.2x): icmp_seq=%d time=%s",
+					       *cp,
 					       hicmp->un.echo.sequence,
-					       tvtoda(&lastpacketsent, &recvtime));
+					       tvtoda(&lastpacketsent,
+						      &recvtime));
 				}
 				if (beep) {
 					printf("\a");
@@ -292,7 +298,8 @@ static void handlepacket(const char *unused, struct pcap_pkthdr *h,
 		}
 	} else {
 		/* ping ip */
-		harp = (struct arphdr*)((char*)eth + sizeof(struct libnet_ethernet_hdr));
+		harp = (struct arphdr*)((char*)eth
+					+ sizeof(struct libnet_ethernet_hdr));
 		if ((htons(harp->ar_op) == ARPOP_REPLY)
 		    && (htons(harp->ar_pro) == ETH_P_IP)
 		    && (htons(harp->ar_hrd) == ARPHRD_ETHER)) {
@@ -304,6 +311,7 @@ static void handlepacket(const char *unused, struct pcap_pkthdr *h,
 				if (!rawoutput && !finddup) {
 					printf("%d bytes from ", h->len);
 				}
+
 				if (!quiet) {
 					if (rawoutput & 1) {
 						for (c = 0; c < harp->ar_hln-1;
@@ -347,6 +355,7 @@ static void recvpackets(void)
 		fprintf(stderr, "pcap_loop(): error\n");
 		exit(1);
 	}
+	// does not return
 }
 
 int main(int argc, char **argv)
@@ -482,7 +491,7 @@ int main(int argc, char **argv)
 		exit(1);
 	}
 	if (getuid() && geteuid()) {
-		fprintf(stderr, "Must be r00t\n");
+		fprintf(stderr, "arping: must run as root\n");
 		return 1;
 	}
 
@@ -538,6 +547,13 @@ int main(int argc, char **argv)
 			fprintf(stderr, "pcap_lookupdev(): %s\n", ebuf);
 			exit(1);
 		}
+		// FIXME: check for other probably-not interfaces
+		if (!strncmp(ifname, "ipsec", 5)) {
+			fprintf(stderr, "arping: Um.. %s looks like the wrong "
+				"interface to use. Is it? "
+				"(-i switch)\n", ifname);
+			fprintf(stderr, "arping: using it anyway this time\n");
+		}
 	}
 
 	if (!(linkint = libnet_open_link_interface(ifname, ebuf))) {
@@ -662,8 +678,7 @@ int main(int argc, char **argv)
 			fprintf(stderr, "libnet_build_arp(): error\n");
 			exit(1);
 		}
-		
-	}
+      	}
 	/*
 	 * pcap init
 	 */
